@@ -1,21 +1,9 @@
-//
-// Copyright (C) 2016~2016 by CSSlayer
-// wengxt@gmail.com
-//
-// This library is free software; you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 2.1 of the
-// License, or (at your option) any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-// Lesser General Public License for more details.
-//
-// You should have received a copy of the GNU Lesser General Public
-// License along with this library; see the file COPYING. If not,
-// see <http://www.gnu.org/licenses/>.
-//
+/*
+ * SPDX-FileCopyrightText: 2016-2016 CSSlayer <wengxt@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ *
+ */
 #ifndef _FCITX_GLOBALCONFIG_H_
 #define _FCITX_GLOBALCONFIG_H_
 
@@ -37,6 +25,7 @@ public:
     GlobalConfig();
     virtual ~GlobalConfig();
     const KeyList &triggerKeys() const;
+    bool enumerateWithTriggerKeys() const;
     const KeyList &altTriggerKeys() const;
     const KeyList &activateKeys() const;
     const KeyList &deactivateKeys() const;
@@ -51,6 +40,9 @@ public:
 
     const KeyList &defaultPrevPage() const;
     const KeyList &defaultNextPage() const;
+
+    const KeyList &defaultPrevCandidate() const;
+    const KeyList &defaultNextCandidate() const;
     int defaultPageSize() const;
 
     const std::vector<std::string> &enabledAddons() const;
